==> gwt-material-table-2.0-rc5.jar: gwt/material/design/client/base/constants/TableCssName.java <==
/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 - 2016 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package gwt.material.design.client.base.constants;

public interface TableCssName {

    String TABLE_BODY = "table-body";
    String TOP_PANEL = "top-panel";
    String INFO_PANEL = "info-panel";
    String TOOL_PANEL = "tool-panel";
    String TABLE = "table";
    String TITLE = "title";
    String STRETCH = "stretch";
    String OVERFLOW_HIDDEN = "overflow-hidden";
    String TABLE_HEADER = "table-header";
    String SUBHEADER = "subheader";
    String EXPANDED = "expanded";
    String DATA_PAGER = "data-pager";
    String ROW = "row";
    String NUM_PAGE_PANEL = "num-page-panel";
    String ROWS_PER_PAGE_PANEL = "rows-per-page-panel";
    String ACTION_PAGE_PANEL = "action-page-panel";
    String SELECTED = "selected";
    String DATA_ROW = "data-row";
    String SELECTION = "selection";
    String WIDGET_CELL = "widget-cell";
    String CELL = "cell";
    String NUMERIC = "numeric";
    String STICKYEXCLUDE = "stickyExclude";
    String COLEX = "colex";
    String SORTABLE = "sortable";
}

==> gwt-material-table-2.6.0-rc1.jar: gwt/material/design/client/base/constants/TableCssName.java <==
/*
 * #%L
 * GwtMaterial
 * %%
 * Copyright (C) 2015 - 2016 GwtMaterialDesign
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
package gwt.material.design.client.base.constants;

public interface TableCssName {

    String TABLE_BODY = "table-body";
    String TOP_PANEL = "top-panel";
    String INFO_PANEL = "info-panel";
    String TOOL_PANEL = "tool-panel";
    String TABLE = "table";
    String TITLE = "title";
    String STRETCH = "stretch";
    String OVERFLOW_HIDDEN = "overflow-hidden";
    String TABLE_HEADER = "table-header";
    String SUBHEADER = "subheader";
    String EXPANDED = "expanded";
    String DATA_PAGER = "data-pager";
    String ROW = "row";
    String NUM_PAGE_PANEL = "num-page-panel";
    String ROWS_PER_PAGE_PANEL = "rows-per-page-panel";
    String ACTION_PAGE_PANEL = "action-page-panel";
    String SELECTED = "selected";
    String DATA_ROW = "data-row";
    String SELECTION = "selection";
    String ARROW_NEXT = "arrow-next";
    String ARROW_PREV = "arrow-prev";
    String WIDGET_CELL = "widget-cell";
    String COMPUTED_CELL = "computed-cell";
    String CELL = "cell";
    String NUMERIC = "numeric";
    String STICKYEXCLUDE = "stickyExclude";
    String COLEX = "colex";
    String SORTABLE = "sortable";
    String FROZEN_COL = "frozen-col";
    String FOOTER_PANEL = "footer-panel";
    String TRUNCATE_COLUMN = "truncate-column";
    String TRUNCATE_HEADER = "truncate-header";
}
